==> kmymoney_5.0.8.orig.tar.xz: kmymoney-5.0.8/kmymoney/plugins/qif/import/qifimporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "mte@users.sourceforge.net",
                "Name": "Michael Edwardes",
                "Name[ca@valencia]": "Michael Edwardes",
                "Name[ca]": "Michael Edwardes",
                "Name[cs]": "Michael Edwardes",
                "Name[de]": "Michael Edwardes",
                "Name[en_GB]": "Michael Edwardes",
                "Name[es]": "Michael Edwardes",
                "Name[fr]": "Michael Edwardes",
                "Name[gl]": "Michael Edwardes",
                "Name[it]": "Michael Edwardes",
                "Name[nl]": "Michael Edwardes",
                "Name[pl]": "Michael Edwardes",
                "Name[pt]": "Michael Edwardes",
                "Name[pt_BR]": "Michael Edwardes",
                "Name[ru]": "Michael Edwardes",
                "Name[sk]": "Michael Edwardes",
                "Name[sv]": "Michael Edwardes",
                "Name[uk]": "Michael Edwardes",
                "Name[x-test]": "xxMichael Edwardesxx"
            }
        ],
        "Description": "Add QIF importing to KMyMoney",
        "Description[ca@valencia]": "Afig la importació des de QIF al KMyMoney",
        "Description[ca]": "Afegeix la importació des de QIF al KMyMoney",
        "Description[de]": "Fügt QIF-Import zu KMyMoney hinzu",
        "Description[en_GB]": "Add QIF importing to KMyMoney",
        "Description[es]": "Añade importación QIF a KMyMoney",
        "Description[fr]": "Ajoute l'importation « QIF » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de importar QIF en KMyMoney",
        "Description[it]": "Aggiunge l'importazione QIF a KMymoney",
        "Description[ko]": "KMyMoney에 QIF 가져오기 추가",
        "Description[nl]": "Voeg QIF importeren toe aan KMyMoney",
        "Description[pl]": "Dodaje importowanie QIF do KMyMoney",
        "Description[pt]": "Adição da importação de QIF para o KMyMoney",
        "Description[pt_BR]": "Adiciona importação QIF no KMyMoney",
        "Description[sk]": "Pridať QIF import do KMyMoney",
        "Description[sv]": "Lägg till QIF-import till KMyMoney",
        "Description[uk]": "Імпортування даних QIF у KMyMoney",
        "Description[x-test]": "xxAdd QIF importing to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "document-import",
        "Id": "qifimporter",
        "License": "GPL",
        "Name": "QIF Importer",
        "Name[ca@valencia]": "importador de QIF",
        "Name[ca]": "importador de QIF",
        "Name[de]": "QIF-Import",
        "Name[en_GB]": "QIF Importer",
        "Name[es]": "Importador QIF",
        "Name[fr]": "Importateur QIF",
        "Name[gl]": "Importador de QIF",
        "Name[it]": "Strumento di importazione QIF",
        "Name[nl]": "QIF importeren",
        "Name[pl]": "Importer QIF",
        "Name[pt]": "Importação de QIF",
        "Name[pt_BR]": "Importador QIF",
        "Name[ru]": "Импорт QIF",
        "Name[sk]": "QIF Importer",
        "Name[sv]": "QIF-import",
        "Name[uk]": "Інструмент імпортування QIF",
        "Name[x-test]": "xxQIF Importerxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.1.0.orig.tar.xz: kmymoney-5.1.0/kmymoney/plugins/qif/import/qifimporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "mte@users.sourceforge.net",
                "Name": "Michael Edwardes",
                "Name[ca@valencia]": "Michael Edwardes",
                "Name[ca]": "Michael Edwardes",
                "Name[cs]": "Michael Edwardes",
                "Name[de]": "Michael Edwardes",
                "Name[en_GB]": "Michael Edwardes",
                "Name[es]": "Michael Edwardes",
                "Name[eu]": "Michael Edwardes",
                "Name[fr]": "Michael Edwardes",
                "Name[gl]": "Michael Edwardes",
                "Name[it]": "Michael Edwardes",
                "Name[ko]": "Michael Edwardes",
                "Name[nl]": "Michael Edwardes",
                "Name[pl]": "Michael Edwardes",
                "Name[pt]": "Michael Edwardes",
                "Name[pt_BR]": "Michael Edwardes",
                "Name[ru]": "Michael Edwardes",
                "Name[sk]": "Michael Edwardes",
                "Name[sv]": "Michael Edwardes",
                "Name[uk]": "Michael Edwardes",
                "Name[x-test]": "xxMichael Edwardesxx"
            }
        ],
        "Description": "Add QIF importing to KMyMoney",
        "Description[ca@valencia]": "Afig la importació des de QIF al KMyMoney",
        "Description[ca]": "Afegeix la importació des de QIF al KMyMoney",
        "Description[de]": "Fügt QIF-Import zu KMyMoney hinzu",
        "Description[en_GB]": "Add QIF importing to KMyMoney",
        "Description[es]": "Añade importación QIF a KMyMoney",
        "Description[eu]": "QIF inportazioa gehitzen dio KMyMoneyri ",
        "Description[fr]": "Ajoute l'importation « QIF » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de importar QIF en KMyMoney",
        "Description[it]": "Aggiunge l'importazione QIF a KMymoney",
        "Description[ko]": "KMyMoney에 QIF 가져오기 추가",
        "Description[nl]": "Voeg QIF importeren toe aan KMyMoney",
        "Description[pl]": "Dodaje importowanie QIF do KMyMoney",
        "Description[pt]": "Adição da importação de QIF para o KMyMoney",
        "Description[pt_BR]": "Adiciona importação QIF no KMyMoney",
        "Description[sk]": "Pridať QIF import do KMyMoney",
        "Description[sv]": "Lägg till QIF-import till KMyMoney",
        "Description[uk]": "Імпортування даних QIF у KMyMoney",
        "Description[x-test]": "xxAdd QIF importing to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "document-import",
        "Id": "qifimporter",
        "License": "GPL",
        "Name": "QIF Importer",
        "Name[ca@valencia]": "Importador de QIF",
        "Name[ca]": "Importador de QIF",
        "Name[de]": "QIF-Import",
        "Name[en_GB]": "QIF Importer",
        "Name[es]": "Importador QIF",
        "Name[eu]": "QIF inportatzailea",
        "Name[fr]": "Importateur QIF",
        "Name[gl]": "Importador de QIF",
        "Name[it]": "Strumento di importazione QIF",
        "Name[ko]": "QIF 가져오기 도구",
        "Name[nl]": "QIF importeren",
        "Name[pl]": "Importer QIF",
        "Name[pt]": "Importação de QIF",
        "Name[pt_BR]": "Importador QIF",
        "Name[ru]": "Импорт QIF",
        "Name[sk]": "QIF Importer",
        "Name[sv]": "QIF-import",
        "Name[uk]": "Інструмент імпортування QIF",
        "Name[x-test]": "xxQIF Importerxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
